==> library-js-0.6.6.jar: library.js <==
(function (_, Kotlin) {
  'use strict';
  var Kind_INTERFACE = Kotlin.Kind.INTERFACE;
  var Exception_init = Kotlin.kotlin.Exception_init_pdl1vj$;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var Exception = Kotlin.kotlin.Exception;
  var LinkedHashSet_init = Kotlin.kotlin.collections.LinkedHashSet_init_287e2$;
  var NotImplementedError_init = Kotlin.kotlin.NotImplementedError;
  var println = Kotlin.kotlin.io.println_s8jyv4$;
  BluetoothPermissionException.prototype = Object.create(Exception.prototype);
  BluetoothPermissionException.prototype.constructor = BluetoothPermissionException;
  BluetoothNotEnabledException.prototype = Object.create(Exception.prototype);
  BluetoothNotEnabledException.prototype.constructor = BluetoothNotEnabledException;
  BluetoothUnsupportedException.prototype = Object.create(Exception.prototype);
  BluetoothUnsupportedException.prototype.constructor = BluetoothUnsupportedException;
  BluetoothResettingException.prototype = Object.create(Exception.prototype);
  BluetoothResettingException.prototype.constructor = BluetoothResettingException;
  BluetoothUnknownException.prototype = Object.create(Exception.prototype);
  BluetoothUnknownException.prototype.constructor = BluetoothUnknownException;
  function BlueFalconDelegate() {
  }
  BlueFalconDelegate.$metadata$ = {
    kind: Kind_INTERFACE,
    simpleName: 'BlueFalconDelegate',
    interfaces: []
  };
  function BluetoothPermissionException(message) {
    if (message === void 0)
      message = 'Permission required for bluetooth';
    Exception_init(message, this);
    this.name = 'BluetoothPermissionException';
  }
  BluetoothPermissionException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothPermissionException',
    interfaces: [Exception]
  };
  function BluetoothNotEnabledException(message) {
    if (message === void 0)
      message = 'Bluetooth is not enabled';
    Exception_init(message, this);
    this.name = 'BluetoothNotEnabledException';
  }
  BluetoothNotEnabledException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothNotEnabledException',
    interfaces: [Exception]
  };
  function BluetoothUnsupportedException(message) {
    if (message === void 0)
      message = 'Bluetooth is not supported on this device';
    Exception_init(message, this);
    this.name = 'BluetoothUnsupportedException';
  }
  BluetoothUnsupportedException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothUnsupportedException',
    interfaces: [Exception]
  };
  function BluetoothResettingException(message) {
    if (message === void 0)
      message = 'Bluetooth service is currently resetting';
    Exception_init(message, this);
    this.name = 'BluetoothResettingException';
  }
  BluetoothResettingException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothResettingException',
    interfaces: [Exception]
  };
  function BluetoothUnknownException(message) {
    if (message === void 0)
      message = 'Unknown error happened';
    Exception_init(message, this);
    this.name = 'BluetoothUnknownException';
  }
  BluetoothUnknownException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothUnknownException',
    interfaces: [Exception]
  };
  function ApplicationContext() {
  }
  ApplicationContext.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApplicationContext',
    interfaces: []
  };
  function BlueFalcon(context, serviceUUID) {
    this.delegates = LinkedHashSet_init();
    this.isScanning = false;
  }
  BlueFalcon.prototype.connect_1tnzz4$ = function (bluetoothPeripheral) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.disconnect_1tnzz4$ = function (bluetoothPeripheral) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.stopScanning = function () {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.scan = function () {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.readCharacteristic_yfc3at$ = function (bluetoothPeripheral, bluetoothCharacteristic) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.writeCharacteristic_l9arxu$ = function (bluetoothPeripheral, bluetoothCharacteristic, value, writeType) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.notifyCharacteristic_feu7vo$ = function (bluetoothPeripheral, bluetoothCharacteristic, notify) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.indicateCharacteristic_feu7vo$ = function (bluetoothPeripheral, bluetoothCharacteristic, indicate) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.notifyAndIndicateCharacteristic_feu7vo$ = function (bluetoothPeripheral, bluetoothCharacteristic, enable) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.readDescriptor_lvieb5$ = function (bluetoothPeripheral, bluetoothCharacteristic, bluetoothCharacteristicDescriptor) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.changeMTU_56n4by$ = function (bluetoothPeripheral, mtuSize) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BlueFalcon',
    interfaces: []
  };
  function BluetoothCharacteristic() {
  }
  Object.defineProperty(BluetoothCharacteristic.prototype, 'name', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothCharacteristic.prototype, 'value', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothCharacteristic.prototype, 'descriptors', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  BluetoothCharacteristic.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothCharacteristic',
    interfaces: []
  };
  function BluetoothCharacteristicDescriptor() {
  }
  BluetoothCharacteristicDescriptor.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothCharacteristicDescriptor',
    interfaces: []
  };
  function BluetoothPeripheral() {
  }
  Object.defineProperty(BluetoothPeripheral.prototype, 'name', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothPeripheral.prototype, 'services', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothPeripheral.prototype, 'uuid', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothPeripheral.prototype, 'rssi', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    },
    set: function (value) {
    }
  });
  BluetoothPeripheral.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothPeripheral',
    interfaces: []
  };
  function BluetoothService() {
  }
  Object.defineProperty(BluetoothService.prototype, 'name', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothService.prototype, 'characteristics', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  BluetoothService.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothService',
    interfaces: []
  };
  function log(message) {
    println(message);
  }
  var package$dev = _.dev || (_.dev = {});
  var package$bluefalcon = package$dev.bluefalcon || (package$dev.bluefalcon = {});
  package$bluefalcon.BlueFalconDelegate = BlueFalconDelegate;
  package$bluefalcon.BluetoothPermissionException = BluetoothPermissionException;
  package$bluefalcon.BluetoothNotEnabledException = BluetoothNotEnabledException;
  package$bluefalcon.BluetoothUnsupportedException = BluetoothUnsupportedException;
  package$bluefalcon.BluetoothResettingException = BluetoothResettingException;
  package$bluefalcon.BluetoothUnknownException = BluetoothUnknownException;
  package$bluefalcon.ApplicationContext = ApplicationContext;
  package$bluefalcon.BlueFalcon = BlueFalcon;
  package$bluefalcon.BluetoothCharacteristic = BluetoothCharacteristic;
  package$bluefalcon.BluetoothCharacteristicDescriptor = BluetoothCharacteristicDescriptor;
  package$bluefalcon.BluetoothPeripheral = BluetoothPeripheral;
  package$bluefalcon.BluetoothService = BluetoothService;
  package$bluefalcon.log_61zpoe$ = log;
  Kotlin.defineModule('library', _);
  return _;
}(module.exports, require('kotlin')));

//# sourceMappingURL=library.js.map

==> library-js-0.6.7.jar: library.js <==
(function (_, Kotlin) {
  'use strict';
  var Kind_INTERFACE = Kotlin.Kind.INTERFACE;
  var Exception_init = Kotlin.kotlin.Exception_init_pdl1vj$;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var Exception = Kotlin.kotlin.Exception;
  var LinkedHashSet_init = Kotlin.kotlin.collections.LinkedHashSet_init_287e2$;
  var NotImplementedError_init = Kotlin.kotlin.NotImplementedError;
  var println = Kotlin.kotlin.io.println_s8jyv4$;
  BluetoothPermissionException.prototype = Object.create(Exception.prototype);
  BluetoothPermissionException.prototype.constructor = BluetoothPermissionException;
  BluetoothNotEnabledException.prototype = Object.create(Exception.prototype);
  BluetoothNotEnabledException.prototype.constructor = BluetoothNotEnabledException;
  BluetoothUnsupportedException.prototype = Object.create(Exception.prototype);
  BluetoothUnsupportedException.prototype.constructor = BluetoothUnsupportedException;
  BluetoothResettingException.prototype = Object.create(Exception.prototype);
  BluetoothResettingException.prototype.constructor = BluetoothResettingException;
  BluetoothUnknownException.prototype = Object.create(Exception.prototype);
  BluetoothUnknownException.prototype.constructor = BluetoothUnknownException;
  function BlueFalconDelegate() {
  }
  BlueFalconDelegate.$metadata$ = {
    kind: Kind_INTERFACE,
    simpleName: 'BlueFalconDelegate',
    interfaces: []
  };
  function BluetoothPermissionException(message) {
    if (message === void 0)
      message = 'Permission required for bluetooth';
    Exception_init(message, this);
    this.name = 'BluetoothPermissionException';
  }
  BluetoothPermissionException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothPermissionException',
    interfaces: [Exception]
  };
  function BluetoothNotEnabledException(message) {
    if (message === void 0)
      message = 'Bluetooth is not enabled';
    Exception_init(message, this);
    this.name = 'BluetoothNotEnabledException';
  }
  BluetoothNotEnabledException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothNotEnabledException',
    interfaces: [Exception]
  };
  function BluetoothUnsupportedException(message) {
    if (message === void 0)
      message = 'Bluetooth is not supported on this device';
    Exception_init(message, this);
    this.name = 'BluetoothUnsupportedException';
  }
  BluetoothUnsupportedException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothUnsupportedException',
    interfaces: [Exception]
  };
  function BluetoothResettingException(message) {
    if (message === void 0)
      message = 'Bluetooth service is currently resetting';
    Exception_init(message, this);
    this.name = 'BluetoothResettingException';
  }
  BluetoothResettingException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothResettingException',
    interfaces: [Exception]
  };
  function BluetoothUnknownException(message) {
    if (message === void 0)
      message = 'Unknown error happened';
    Exception_init(message, this);
    this.name = 'BluetoothUnknownException';
  }
  BluetoothUnknownException.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothUnknownException',
    interfaces: [Exception]
  };
  function ApplicationContext() {
  }
  ApplicationContext.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'ApplicationContext',
    interfaces: []
  };
  function BlueFalcon(context, serviceUUID) {
    this.delegates = LinkedHashSet_init();
    this.isScanning = false;
  }
  BlueFalcon.prototype.connect_1tnzz4$ = function (bluetoothPeripheral) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.disconnect_1tnzz4$ = function (bluetoothPeripheral) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.stopScanning = function () {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.scan = function () {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.readCharacteristic_yfc3at$ = function (bluetoothPeripheral, bluetoothCharacteristic) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.writeCharacteristic_l9arxu$ = function (bluetoothPeripheral, bluetoothCharacteristic, value, writeType) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.writeCharacteristic_5wdhue$ = function (bluetoothPeripheral, bluetoothCharacteristic, value, writeType) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.notifyCharacteristic_feu7vo$ = function (bluetoothPeripheral, bluetoothCharacteristic, notify) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.indicateCharacteristic_feu7vo$ = function (bluetoothPeripheral, bluetoothCharacteristic, indicate) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.notifyAndIndicateCharacteristic_feu7vo$ = function (bluetoothPeripheral, bluetoothCharacteristic, enable) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.readDescriptor_lvieb5$ = function (bluetoothPeripheral, bluetoothCharacteristic, bluetoothCharacteristicDescriptor) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.prototype.changeMTU_56n4by$ = function (bluetoothPeripheral, mtuSize) {
    throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
  };
  BlueFalcon.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BlueFalcon',
    interfaces: []
  };
  function BluetoothCharacteristic() {
  }
  Object.defineProperty(BluetoothCharacteristic.prototype, 'name', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothCharacteristic.prototype, 'value', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothCharacteristic.prototype, 'descriptors', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  BluetoothCharacteristic.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothCharacteristic',
    interfaces: []
  };
  function BluetoothCharacteristicDescriptor() {
  }
  BluetoothCharacteristicDescriptor.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothCharacteristicDescriptor',
    interfaces: []
  };
  function BluetoothPeripheral() {
  }
  Object.defineProperty(BluetoothPeripheral.prototype, 'name', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothPeripheral.prototype, 'services', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothPeripheral.prototype, 'uuid', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothPeripheral.prototype, 'rssi', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    },
    set: function (value) {
    }
  });
  BluetoothPeripheral.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothPeripheral',
    interfaces: []
  };
  function BluetoothService() {
  }
  Object.defineProperty(BluetoothService.prototype, 'name', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  Object.defineProperty(BluetoothService.prototype, 'characteristics', {
    get: function () {
      throw new NotImplementedError_init('An operation is not implemented: ' + 'not implemented');
    }
  });
  BluetoothService.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'BluetoothService',
    interfaces: []
  };
  function log(message) {
    println(message);
  }
  var package$dev = _.dev || (_.dev = {});
  var package$bluefalcon = package$dev.bluefalcon || (package$dev.bluefalcon = {});
  package$bluefalcon.BlueFalconDelegate = BlueFalconDelegate;
  package$bluefalcon.BluetoothPermissionException = BluetoothPermissionException;
  package$bluefalcon.BluetoothNotEnabledException = BluetoothNotEnabledException;
  package$bluefalcon.BluetoothUnsupportedException = BluetoothUnsupportedException;
  package$bluefalcon.BluetoothResettingException = BluetoothResettingException;
  package$bluefalcon.BluetoothUnknownException = BluetoothUnknownException;
  package$bluefalcon.ApplicationContext = ApplicationContext;
  package$bluefalcon.BlueFalcon = BlueFalcon;
  package$bluefalcon.BluetoothCharacteristic = BluetoothCharacteristic;
  package$bluefalcon.BluetoothCharacteristicDescriptor = BluetoothCharacteristicDescriptor;
  package$bluefalcon.BluetoothPeripheral = BluetoothPeripheral;
  package$bluefalcon.BluetoothService = BluetoothService;
  package$bluefalcon.log_61zpoe$ = log;
  Kotlin.defineModule('library', _);
  return _;
}(module.exports, require('kotlin')));

//# sourceMappingURL=library.js.map
